#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-lib
version:              0.1
visibility:           public
id:                   doctest-lib-0.1-I4xPf7Yx2sgAG6MES8YooM
key:                  doctest-lib-0.1-I4xPf7Yx2sgAG6MES8YooM
license:              MIT
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:
    Henning Thielemann <haskell@henning-thielemann.de>, Simon Hengel <sol@typeful.net>

homepage:             https://hub.darcs.net/thielema/doctest-lib/
synopsis:             Parts of doctest exposed as library
description:
    Parts of doctest exposed as library.
    For use with the doctest-extract utility.

category:             Testing
abi:                  0d1a19a466b3c06ffac8e609d3025d97
exposed:              True
exposed-modules:
    Test.DocTest.Base Test.DocTest.Location Test.DocTest.Parse

import-dirs:          /usr/lib/ghc-8.10.5/site-local/doctest-lib-0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/doctest-lib-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/doctest-lib-0.1
hs-libraries:         HSdoctest-lib-0.1-I4xPf7Yx2sgAG6MES8YooM
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-doctest-lib/html/doctest-lib.haddock
haddock-html:         /usr/share/doc/haskell-doctest-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

